---
title: Django SVCS
---

[![image](https://img.shields.io/pypi/v/django_svcs.svg)](https://pypi.python.org/pypi/django_svcs)

[![image](https://img.shields.io/travis/offbyone/django_svcs.svg)](https://travis-ci.com/offbyone/django_svcs)

[![Documentation Status](https://readthedocs.org/projects/django-svcs/badge/?version=latest)](https://django-svcs.readthedocs.io/en/latest/?version=latest)

A Django integration for SVCS

-   Free software: BSD license
-   Documentation: <https://django-svcs.readthedocs.io>.

# Features

-   TODO

# Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.
